/**
 * @file
 * Provides SlickLightbox loader.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  /**
   * SlickLightbox utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} elm
   *   The SlickLightbox HTML element.
   */
  function doSlickLightbox(i, elm) {
    var settings = drupalSettings.slickLightbox || {};
    var options = {
      // @todo use [data-slick-lightbox-trigger] post Blazy 1.x update/ release.
      itemSelector: 'a.litebox',
      caption: function (target, info) {
        return $(target).next('.litebox-caption').length ? $(target).next('.litebox-caption').html() : '';
      },
      slick: settings,
      lazy: settings.lazyLoad ? true : false
    };

    $(elm).slickLightbox(options);
  }

  /**
   * Attaches Slick Lightbox behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.slickLightbox = {
    attach: function (context) {
      $('[data-slick-lightbox-gallery]', context).once('slick-lightbox').each(doSlickLightbox);
    }
  };

})(jQuery, Drupal, drupalSettings);
